<?php # $Id: lang_fr.inc.php 2093 2008-01-18 12:50:00Z garvinhicking $

##########################################################################
# serendipity - another blogger...                                       #
##########################################################################
#                                                                        #
# (c) 2003 Jannis Hermanns <J@hacked.it>                                 #
# http://www.jannis.to/programming/serendipity.html                      #
#                                                                        #
# Translated by                                                          #
# Sebastian Mordziol <argh@php-tools.net>                                #
# http://sebastian.mordziol.de                                           #
#                                                                        #
##########################################################################

@define('PLUGIN_EVENT_TEXTILE_NAME', 'Balises: Textile');
@define('PLUGIN_EVENT_TEXTILE_DESC', 'Permet l\'utilisation de balises Textile dans le texte des billets');
@define('PLUGIN_EVENT_TEXTILE_TRANSFORM', 'Syntaxe <a href="%s">Textile</a> autorisée');

/* vim: set sts=4 ts=4 expandtab : */
?>